@@ -13,8 +13,12 @@ class TestIncludeme(unittest.TestCase):
 
         includeme(config)
 
-        config.add_route.assert_called_with('clientlogs', mock.ANY,
-                                            request_method='POST')
+        config.add_route.assert_any_call('clientlogs', mock.ANY,
+                                         request_method='POST')
+
+        config.add_route.assert_any_call('clientlogs_batch',
+                                         '/clientlogs/batch',
+                                         request_method='POST')
         config.scan.assert_called_with('pyramid_restlogging.views')
         config.commit.assert_called_with()
 
